@@ -1,7 +1,7 @@
 package Future::HTTP;
 use strict;
 use Filter::signatures;
-no warnings 'experimental';
+no warnings 'experimental::signatures';
 use feature 'signatures';
 
 =head1 NAME
@@ -29,7 +29,7 @@ but has not materialized yet.
 =cut
 
 use vars qw($implementation @loops $VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 @loops = (
     # Mojolicious support would be nice, should use Future::Mojo and Mojolicious::UserAgent I guess
