@@ -2,13 +2,13 @@ package # hide from indexer as it's not really ready
     Future::HTTP::API::HTTPTiny;
 use strict;
 use Filter::signatures;
-no warnings 'experimental';
+no warnings 'experimental::signatures';
 use feature 'signatures';
 require HTTP::Tiny;
 require URI;
 
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 =head1 NAME
 
